==> memoiR_0.5-0.tar.gz: memoiR/README.md <==
# memoiR <img src="man/figures/logo.png" align="right" alt="" width="120" />

![stability-wip](https://img.shields.io/badge/lifecycle-maturing-blue.svg)
![R-CMD-check](https://github.com/EricMarcon/memoiR/workflows/R-CMD-check/badge.svg)
[![codecov](https://codecov.io/github/EricMarcon/memoiR/branch/master/graphs/badge.svg)](https://codecov.io/github/EricMarcon/memoiR) 


Templates to publish well-formatted documents both in HTML and PDF formats.

Gallery:

- Memoir:
    - [HTML GitBook](https://ericmarcon.github.io/memoiR/gallery/memoir/bookdown_gitbook/index.html)
    - [PDF](https://ericmarcon.github.io/memoiR/gallery/memoir/bookdown_pdf_book/MyBook.pdf)
- Simple article: 
    - [HTML Document](https://ericmarcon.github.io/memoiR/gallery/simple_article/bookdown_html_document2/simple_article.html)
    - [Downcute HTML](https://ericmarcon.github.io/memoiR/gallery/simple_article/rmdformats_downcute/simple_article.html)
    - The HTML Gitbook format is similar to that of the [memoir](https://ericmarcon.github.io/memoiR/gallery/memoir/bookdown_gitbook/index.html) template
    - [PDF](https://ericmarcon.github.io/memoiR/gallery/simple_article/bookdown_pdf_book/simple_article.pdf)
- Stylish article: 
    - [PDF](https://ericmarcon.github.io/memoiR/gallery/stylish_article/bookdown_pdf_book/stylish_article.pdf)
    - HTML outputs are identical to those of the Simple Article
- Beamer Presentation: 
    - [HTML IOSlide](https://ericmarcon.github.io/memoiR/gallery/beamer_presentation/bookdown_ioslides_presentation2/beamer_presentation.html)
    - [HTML Slidy](https://ericmarcon.github.io/memoiR/gallery/beamer_presentation/bookdown_slidy_presentation2/beamer_presentation.html)
    - [PDF (Beamer)](https://ericmarcon.github.io/memoiR/gallery/beamer_presentation/bookdown_beamer_presentation2/beamer_presentation.pdf)

A quick [introduction](https://ericmarcon.github.io/memoiR/articles/memoiR.html) is in `vignette("memoiR")`.

==> memoiR_1.0-0.tar.gz: memoiR/README.md <==
# memoiR <img src="man/figures/logo.png" align="right" alt="" width="120" />

![stability-wip](https://img.shields.io/badge/lifecycle-maturing-blue.svg)
![R-CMD-check](https://github.com/EricMarcon/memoiR/workflows/R-CMD-check/badge.svg)
[![codecov](https://codecov.io/github/EricMarcon/memoiR/branch/master/graphs/badge.svg)](https://codecov.io/github/EricMarcon/memoiR)
[![CRAN version](http://www.r-pkg.org/badges/version/memoiR)](https://CRAN.r-project.org/package=memoiR)
[![](http://cranlogs.r-pkg.org/badges/memoiR)](https://CRAN.R-project.org/package=memoiR)


Templates to publish well-formatted documents both in HTML and PDF formats.

Gallery:

- Memoir:
    - [HTML GitBook](https://ericmarcon.github.io/memoiR/gallery/memoir/bookdown_gitbook/index.html)
    - [PDF, small-margin layout](https://ericmarcon.github.io/memoiR/gallery/memoir/bookdown_pdf_book/MyBook.pdf)
    - [PDF, wide-margin layout](https://ericmarcon.github.io/travailleR/travailleR.pdf)
- Simple article: 
    - [HTML Document](https://ericmarcon.github.io/memoiR/gallery/simple_article/bookdown_html_document2/simple_article.html)
    - [Downcute HTML](https://ericmarcon.github.io/memoiR/gallery/simple_article/rmdformats_downcute/simple_article.html)
    - The HTML Gitbook format is similar to that of the [memoir](https://ericmarcon.github.io/memoiR/gallery/memoir/bookdown_gitbook/index.html) template
    - [PDF](https://ericmarcon.github.io/memoiR/gallery/simple_article/bookdown_pdf_book/simple_article.pdf)
- Stylish article: 
    - [PDF](https://ericmarcon.github.io/memoiR/gallery/stylish_article/bookdown_pdf_book/stylish_article.pdf)
    - HTML outputs are identical to those of the Simple Article
- Beamer Presentation: 
    - [HTML IOSlide](https://ericmarcon.github.io/memoiR/gallery/beamer_presentation/bookdown_ioslides_presentation2/beamer_presentation.html)
    - [HTML Slidy](https://ericmarcon.github.io/memoiR/gallery/beamer_presentation/bookdown_slidy_presentation2/beamer_presentation.html)
    - [PDF (Beamer)](https://ericmarcon.github.io/memoiR/gallery/beamer_presentation/bookdown_beamer_presentation2/beamer_presentation.pdf)

A quick [introduction](https://ericmarcon.github.io/memoiR/articles/memoiR.html) is in `vignette("memoiR")`.
